==> unify_api-1.0.4.tar.gz: lib/src/impl/unsupported.dart <==
library unify.impl.unsupported;

import 'dart:async';
import 'dart:io';

import '../../unify.dart';

class UnifyClientImpl implements UnifyClient {
  UnifyClientImpl(String email, String password, UnifyAccessToken token,
      UnifyApiEndpoints endpoints) {
    throw "This platform is not supported.";
  }

  @override
  String get email => throw "This platform is not supported.";

  @override
  String get password => throw "This platform is not supported.";

  @override
  UnifyAccessToken get token => throw "This platform is not supported.";

  @override
  set token(UnifyAccessToken token) => throw "This platform is not supported.";

  @override
  bool get isAuthorized => throw "This platform is not supported.";

  @override
  UnifyApiEndpoints get endpoints => throw "This platform is not supported.";

  @override
  Future login() {
    throw "This platform is not supported.";
  }

  @override
  Future logout() {
    throw "This platform is not supported.";
  }

  @override
  Future close() {
    throw "This platform is not supported.";
  }

  @override
  Future<AccountInfo> getInfo() {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Contact>> listContacts(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<ContactDetails> getContactDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<LeadDetails> getLeadDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Lead>> listLeads(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<DashboardAlert>> listCustomerAlerts(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<DashboardAlert>> listHotProspectAlerts(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<DashboardAlert>> listOpportunitiyAlerts(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<DashboardAlert>> listPipelineAlerts(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<ContactNote>> listContactNotes(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<LeadNote>> listLeadNotes(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future addContactNote(String id, String text) {
    throw "This platform is not supported.";
  }

  @override
  Future addLeadNote(String id, String text) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Tracker>> listContactTracker(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Tracker>> listLeadTracker(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<ContactGroup>> listContactGroups({bool totals = true}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<LeadGroup>> listLeadGroups({bool totals = true}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Contact>> listContactsForContactGroup(String id,
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Lead>> listLeadsForLeadGroup(String id,
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<String>> listEmailsForContactGroup(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<String>> listEmailsForLeadGroup(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Loan>> listLoansAll(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Loan>> listLoansClosed(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Loan>> listLoansMyPipeline(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Loan>> listLoansProspects(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<LoanDetails> getLoanDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<AccountInfo> getUser(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksAll({DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksContacts({DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksForContact(String id, {DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksForLead(String id, {DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksLeads({DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksCoreLeads({DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksForCoreLead(String id, {DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<CoreLead>> listCoreLeads(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<CoreLeadDetails> getCoreLeadDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<DashboardStats> getStats() {
    throw "This platform is not supported.";
  }

  @override
  Future<List<LoanContact>> listLoanContacts(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<LoanProgress> getLoanStatus(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Loan>> listLoansOther(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<LoanHistory>> listLoanHistory(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<String>> listContactLogResponses() {
    throw "This platform is not supported.";
  }

  @override
  Future<List<String>> listLeadLogResponses() {
    throw "This platform is not supported.";
  }

  @override
  Future addContactLogResponse(String id, {String action, String comment}) {
    throw "This platform is not supported.";
  }

  @override
  Future addLeadLogResponse(String id, {String action, String comment}) {
    throw "This platform is not supported.";
  }

  @override
  Future addContactFollowUp(String id,
      {String title,
      DateTime date,
      int type = 0,
      String description = "",
      bool dismissOnChange = true,
      String alertType,
      int alertOffset = 0,
      String userNumber,
      String prospectNumber}) {
    throw "This platform is not supported.";
  }

  @override
  Future addLeadFollowUp(String id,
      {String title,
      DateTime date,
      int type = 0,
      String description = "",
      bool dismissOnChange = true,
      String alertType,
      int alertOffset = 0,
      String userNumber,
      String prospectNumber}) {
    throw "This platform is not supported.";
  }

  @override
  Future addContactGroup(String name) {
    throw "This platform is not supported.";
  }

  @override
  Future addLeadGroup(String name) {
    throw "This platform is not supported.";
  }

  @override
  Future editContactGroup(String id, String name) {
    throw "This platform is not supported.";
  }

  @override
  Future editLeadGroup(String id, String name) {
    throw "This platform is not supported.";
  }

  @override
  Future addContact({
    String firstName,
    String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    String secondaryEmail,
    String loanNumber,
    int contactPriority,
    CompanyCategory companyCategory,
    List<ContactGroup> groups,
  }) {
    throw "This platform is not supported.";
  }

  @override
  Future editContact(
    String id, {
    String firstName,
    String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    String secondaryEmail,
    String loanNumber,
    int contactPriority,
    CompanyCategory companyCategory,
    List<ContactGroup> groups,
  }) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<CompanyCategory>> listCompanyCategories() {
    throw "This platform is not supported.";
  }

  @override
  Future addLead(
      {String firstName,
      String lastName,
      String middleName,
      String suffix,
      String secondaryFirstName,
      String secondaryMiddleName,
      String secondaryLastName,
      PostalAddress currentAddress,
      PostalAddress propertyAddress,
      PhoneNumber cellPhone,
      PhoneNumber homePhone,
      PhoneNumber officePhone,
      PhoneNumber faxPhone,
      PhoneNumber secondaryCellPhone,
      String email,
      List<LeadGroup> groups,
      String bestCallTime,
      String creditRange,
      String secondaryCreditRange,
      double annualGrossIncome,
      bool recentBankruptcy,
      double propertyValue}) {
    throw "This platform is not supported.";
  }

  @override
  Future editLead(String id,
      {String firstName,
      String lastName,
      String middleName,
      String suffix,
      String secondaryFirstName,
      String secondaryMiddleName,
      String secondaryLastName,
      PostalAddress currentAddress,
      PostalAddress propertyAddress,
      PhoneNumber cellPhone,
      PhoneNumber homePhone,
      PhoneNumber officePhone,
      PhoneNumber faxPhone,
      PhoneNumber secondaryCellPhone,
      String email,
      List<LeadGroup> groups,
      String bestCallTime,
      String creditRange,
      String secondaryCreditRange,
      double annualGrossIncome,
      bool recentBankruptcy,
      double propertyValue}) {
    throw "This platform is not supported.";
  }

  @override
  Future<UnifyCache> getCache({bool all = false}) {
    throw "This platform is not supported.";
  }

  @override
  Future<VideoDetails> getVideoDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Video>> listVideosAll(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Video>> listVideosArchived(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Video>> listVideosMyVideos(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Video>> listVideosShared(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<String> getKalturaSession(String kalturaID, {bool admin = false}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<String>> listTemplates() {
    throw "This platform is not supported.";
  }

  @override
  Future<int> getVideoTotalViews() {
    throw "This platform is not supported.";
  }

  @override
  Future<String> getVideoPreview(String id,
      {String name, String body, String template}) {
    throw "This platform is not supported.";
  }

  @override
  Future<String> getVideoShareUrl(String id, {String template = "MESSAGE"}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<MarketingSection>> listMarketingSection() {
    throw "This platform is not supported.";
  }

  @override
  Future<List<MarketingMaterial>> listMarketingMaterial(
      {String type, String category, String subCategory, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<MarketingMaterialDetails> getMarketingDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<MarketingCampaign>> listMarketingCampaigns(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<MarketingPartner>> listMarketingPartners() {
    throw "This platform is not supported.";
  }

  @override
  Future deleteDashboardAlert(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future restoreDashboardAlert(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteContact(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteLead(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteTask(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteCartItem(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteCartCard(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<CartItem>> listCartItems() {
    throw "This platform is not supported.";
  }

  @override
  Future<CartOrder> getCartOrder() {
    throw "This platform is not supported.";
  }

  @override
  Future<MarketingValidation> getMarketingValidation(String id,
      {String partnerId,
      bool sendNow,
      DateTime startDate,
      List<String> contactIds,
      List<String> leadIds}) {
    throw "This platform is not supported.";
  }

  @override
  Future addMarketingCampaignToCart(String id,
      {String partnerId,
      bool sendNow,
      DateTime startDate,
      List<String> contactIds,
      List<String> leadIds}) {
    throw "This platform is not supported.";
  }

  @override
  Future startMarketingCampaign(String id,
      {String partnerId,
      bool sendNow,
      DateTime startDate,
      List<String> contactIds,
      List<String> leadIds}) {
    throw "This platform is not supported.";
  }

  @override
  Future startVideoQuickSend(
    String id, {
    bool cc,
    List<String> emails,
    String subject,
    String body,
    String name,
    String template,
  }) {
    throw "This platform is not supported.";
  }

  @override
  Future batchDeleteContacts(List<Contact> contacts) {
    throw "This platform is not supported.";
  }

  @override
  Future batchDeleteLeads(List<Lead> leads) {
    throw "This platform is not supported.";
  }

  @override
  Future batchRestoreContacts(List<Contact> contacts) {
    throw "This platform is not supported.";
  }

  @override
  Future batchRestoreLeads(List<Lead> leads) {
    throw "This platform is not supported.";
  }

  @override
  Future batchDeleteDashboardAlerts(List<DashboardAlert> alerts) {
    throw "This platform is not supported.";
  }

  @override
  Future batchRestoreDashboardAlerts(List<DashboardAlert> alerts) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<DashboardPartners>> listDashboardPartners(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteContactGroup(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteLeadGroup(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteMarketingCampiagn(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<UnifyAlert>> listUnifyAlerts(
      {String type, String priority, DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteUnifyAlert(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<String> getAccountStatus({String username, String password}) {
    throw "This platform is not supported.";
  }

  @override
  Future<num> getAccountBalance() {
    throw "This platform is not supported.";
  }

  @override
  Future editVideoInfo(String id, {String name, String description}) {
    throw "This platform is not supported.";
  }

  @override
  Future uploadVideoThumbnail(String id, File image) {
    throw "This platform is not supported.";
  }

  @override
  Future uploadVideo(File video, {String name, String description}) {
    throw "This platform is not supported.";
  }
}

==> unify_api-1.2.0.tar.gz: lib/src/impl/unsupported.dart <==
library unify.impl.unsupported;

import 'dart:async';
import 'dart:io';

import '../../unify.dart';

class UnifyClientImpl implements UnifyClient {
  UnifyClientImpl(String email, String password, UnifyAccessToken token,
      UnifyApiEndpoints endpoints) {
    throw "This platform is not supported.";
  }

  @override
  String get email => throw "This platform is not supported.";

  @override
  String get password => throw "This platform is not supported.";

  @override
  UnifyAccessToken get token => throw "This platform is not supported.";

  @override
  set token(UnifyAccessToken token) => throw "This platform is not supported.";

  @override
  bool get isAuthorized => throw "This platform is not supported.";

  @override
  UnifyApiEndpoints get endpoints => throw "This platform is not supported.";

  @override
  Future login() {
    throw "This platform is not supported.";
  }

  @override
  Future logout() {
    throw "This platform is not supported.";
  }

  @override
  Future close() {
    throw "This platform is not supported.";
  }

  @override
  Future<AccountInfo> getInfo() {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Contact>> listContacts(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<ContactDetails> getContactDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<LeadDetails> getLeadDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Lead>> listLeads(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<DashboardAlert>> listCustomerAlerts(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<DashboardAlert>> listHotProspectAlerts(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<DashboardAlert>> listOpportunitiyAlerts(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<DashboardAlert>> listPipelineAlerts(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<ContactNote>> listContactNotes(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<LeadNote>> listLeadNotes(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future addContactNote(String id, String text) {
    throw "This platform is not supported.";
  }

  @override
  Future addLeadNote(String id, String text) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Timeline>> listContactTimeline(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Timeline>> listLeadTimeline(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<ContactGroup>> listContactGroups({bool totals = true}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<LeadGroup>> listLeadGroups({bool totals = true}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Contact>> listContactsForContactGroup(String id,
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Lead>> listLeadsForLeadGroup(String id,
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<String>> listEmailsForContactGroup(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<String>> listEmailsForLeadGroup(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<LoanDetails> getLoanDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<AccountInfo> getUser(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksAll({DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksContacts({DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksForContact(String id, {DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksForLead(String id, {DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksLeads({DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksCoreLeads({DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Task>> listTasksForCoreLead(String id, {DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<CoreLead>> listCoreLeads(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<CoreLeadDetails> getCoreLeadDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<DashboardStats> getStats() {
    throw "This platform is not supported.";
  }

  @override
  Future<List<LoanContact>> listLoanContacts(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<LoanProgress> getLoanStatus(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Loan>> listLoans({
    int page = 1,
    int rows = 100,
    String query = "",
    LoansFolder folder = LoansFolder.all,
  }) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<LoanHistory>> listLoanHistory(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<String>> listContactLogResponses() {
    throw "This platform is not supported.";
  }

  @override
  Future<List<String>> listLeadLogResponses() {
    throw "This platform is not supported.";
  }

  @override
  Future addContactLogResponse(String id, {String action, String comment}) {
    throw "This platform is not supported.";
  }

  @override
  Future addLeadLogResponse(String id, {String action, String comment}) {
    throw "This platform is not supported.";
  }

  @override
  Future addContactFollowUp(String id,
      {String title,
      DateTime date,
      int type = 0,
      String description = "",
      bool dismissOnChange = true,
      String alertType,
      int alertOffset = 0,
      String userNumber,
      String prospectNumber}) {
    throw "This platform is not supported.";
  }

  @override
  Future addLeadFollowUp(String id,
      {String title,
      DateTime date,
      int type = 0,
      String description = "",
      bool dismissOnChange = true,
      String alertType,
      int alertOffset = 0,
      String userNumber,
      String prospectNumber}) {
    throw "This platform is not supported.";
  }

  @override
  Future addContactGroup(String name) {
    throw "This platform is not supported.";
  }

  @override
  Future addLeadGroup(String name) {
    throw "This platform is not supported.";
  }

  @override
  Future editContactGroup(String id, String name) {
    throw "This platform is not supported.";
  }

  @override
  Future editLeadGroup(String id, String name) {
    throw "This platform is not supported.";
  }

  @override
  Future addContact({
    String firstName,
    String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    String secondaryEmail,
    String loanNumber,
    int contactPriority,
    CompanyCategory companyCategory,
    List<ContactGroup> groups,
  }) {
    throw "This platform is not supported.";
  }

  @override
  Future editContact(
    String id, {
    String firstName,
    String lastName,
    String middleName,
    String suffix,
    String secondaryFirstName,
    String secondaryMiddleName,
    String secondaryLastName,
    PostalAddress currentAddress,
    PhoneNumber cellPhone,
    PhoneNumber homePhone,
    PhoneNumber officePhone,
    PhoneNumber faxPhone,
    PhoneNumber secondaryCellPhone,
    String email,
    String secondaryEmail,
    String loanNumber,
    int contactPriority,
    CompanyCategory companyCategory,
    List<ContactGroup> groups,
  }) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<CompanyCategory>> listCompanyCategories() {
    throw "This platform is not supported.";
  }

  @override
  Future addLead(
      {String firstName,
      String lastName,
      String middleName,
      String suffix,
      String secondaryFirstName,
      String secondaryMiddleName,
      String secondaryLastName,
      PostalAddress currentAddress,
      PostalAddress propertyAddress,
      PhoneNumber cellPhone,
      PhoneNumber homePhone,
      PhoneNumber officePhone,
      PhoneNumber faxPhone,
      PhoneNumber secondaryCellPhone,
      String email,
      List<LeadGroup> groups,
      String bestCallTime,
      String creditRange,
      String secondaryCreditRange,
      double annualGrossIncome,
      bool recentBankruptcy,
      double propertyValue}) {
    throw "This platform is not supported.";
  }

  @override
  Future editLead(String id,
      {String firstName,
      String lastName,
      String middleName,
      String suffix,
      String secondaryFirstName,
      String secondaryMiddleName,
      String secondaryLastName,
      PostalAddress currentAddress,
      PostalAddress propertyAddress,
      PhoneNumber cellPhone,
      PhoneNumber homePhone,
      PhoneNumber officePhone,
      PhoneNumber faxPhone,
      PhoneNumber secondaryCellPhone,
      String email,
      List<LeadGroup> groups,
      String bestCallTime,
      String creditRange,
      String secondaryCreditRange,
      double annualGrossIncome,
      bool recentBankruptcy,
      double propertyValue}) {
    throw "This platform is not supported.";
  }

  @override
  Future<UnifyCache> getCache({bool all = false}) {
    throw "This platform is not supported.";
  }

  @override
  Future<VideoDetails> getVideoDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Video>> listVideosAll(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Video>> listVideosArchived(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Video>> listVideosMyVideos(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<Video>> listVideosShared(
      {int page = 1, int rows = 100, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<String> getKalturaSession(String kalturaID, {bool admin = false}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<String>> listTemplates() {
    throw "This platform is not supported.";
  }

  @override
  Future<int> getVideoTotalViews() {
    throw "This platform is not supported.";
  }

  @override
  Future<String> getVideoPreview(String id,
      {String name, String body, String template}) {
    throw "This platform is not supported.";
  }

  @override
  Future<String> getVideoShareUrl(String id, {String template = "MESSAGE"}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<MarketingSection>> listMarketingSection() {
    throw "This platform is not supported.";
  }

  @override
  Future<List<MarketingMaterial>> listMarketingMaterial(
      {String type, String category, String subCategory, String query = ""}) {
    throw "This platform is not supported.";
  }

  @override
  Future<MarketingMaterialDetails> getMarketingDetails(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<MarketingCampaign>> listMarketingCampaigns(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<MarketingPartner>> listMarketingPartners() {
    throw "This platform is not supported.";
  }

  @override
  Future deleteDashboardAlert(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future restoreDashboardAlert(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteContact(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteLead(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteTask(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteCartItem(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteCartCard(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<CartItem>> listCartItems() {
    throw "This platform is not supported.";
  }

  @override
  Future<CartOrder> getCartOrder() {
    throw "This platform is not supported.";
  }

  @override
  Future<MarketingValidation> getMarketingValidation(String id,
      {String partnerId,
      bool sendNow,
      DateTime startDate,
      List<String> contactIds,
      List<String> leadIds}) {
    throw "This platform is not supported.";
  }

  @override
  Future addMarketingCampaignToCart(String id,
      {String partnerId,
      bool sendNow,
      DateTime startDate,
      List<String> contactIds,
      List<String> leadIds}) {
    throw "This platform is not supported.";
  }

  @override
  Future startMarketingCampaign(String id,
      {String partnerId,
      bool sendNow,
      DateTime startDate,
      List<String> contactIds,
      List<String> leadIds}) {
    throw "This platform is not supported.";
  }

  @override
  Future startVideoQuickSend(
    String id, {
    bool cc,
    List<String> emails,
    String subject,
    String body,
    String name,
    String template,
  }) {
    throw "This platform is not supported.";
  }

  @override
  Future batchDeleteContacts(List<Contact> contacts) {
    throw "This platform is not supported.";
  }

  @override
  Future batchDeleteLeads(List<Lead> leads) {
    throw "This platform is not supported.";
  }

  @override
  Future batchRestoreContacts(List<Contact> contacts) {
    throw "This platform is not supported.";
  }

  @override
  Future batchRestoreLeads(List<Lead> leads) {
    throw "This platform is not supported.";
  }

  @override
  Future batchDeleteDashboardAlerts(List<DashboardAlert> alerts) {
    throw "This platform is not supported.";
  }

  @override
  Future batchRestoreDashboardAlerts(List<DashboardAlert> alerts) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<DashboardPartners>> listDashboardPartners(
      {int page = 1, int rows = 100}) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteContactGroup(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteLeadGroup(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteMarketingCampiagn(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<List<UnifyAlert>> listUnifyAlerts(
      {String type, String priority, DateTime date}) {
    throw "This platform is not supported.";
  }

  @override
  Future deleteUnifyAlert(String id) {
    throw "This platform is not supported.";
  }

  @override
  Future<String> getAccountStatus({String username, String password}) {
    throw "This platform is not supported.";
  }

  @override
  Future<num> getAccountBalance() {
    throw "This platform is not supported.";
  }

  @override
  Future editVideoInfo(String id, {String name, String description}) {
    throw "This platform is not supported.";
  }

  @override
  Future uploadVideoThumbnail(String id, File image) {
    throw "This platform is not supported.";
  }

  @override
  Future uploadVideo(File video, {String name, String description}) {
    throw "This platform is not supported.";
  }

  @override
  Future<AccountStats> getTotals() {
    throw "This platform is not supported.";
  }
}
